lists.Member (List membership) — amici1

# `lists.Member` (List membership)

Member(id, seqno, list, partner, remark)

Master tables : lists.AllMembers (List memberships), lists.Members (List memberships)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- No. (seqno) : The sequence number of this item with its parent.

- Partner List (list) : See `<django.db.models.fields.related.ForeignKey: list>`.

- Partner (partner) : See `<django.db.models.fields.related.ForeignKey: partner>`.

- Remark (remark) : See `<django.db.models.fields.CharField: remark>`.

- Move (move_buttons) : Displays buttons for certain actions on this row:

- Name (name_column) : See `lino_xl.lib.lists.models.Member.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.lists.models.Member.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.lists.models.Member.overview`.

Referenced from

## Database fields

Internal name | Verbose name | Help text
id | ID |
seqno | No. | The sequence number of this item with its parent.
list | Partner List |
partner | Partner |
remark | Remark |
move_buttons | Move | Displays buttons for certain actions on this row:
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |